pub struct InputSubqueryAggregation {
pub snark_header: EnhancedSnark,
pub snark_account: Option<EnhancedSnark>,
pub snark_storage: Option<EnhancedSnark>,
pub snark_solidity_mapping: Option<EnhancedSnark>,
pub snark_tx: Option<EnhancedSnark>,
pub snark_receipt: Option<EnhancedSnark>,
pub promise_commit_keccak: Fr,
pub snark_results_root: EnhancedSnark,
}Fields
snark_header: EnhancedSnarkHeader snark always required
snark_account: Option<EnhancedSnark>snark_storage: Option<EnhancedSnark>snark_solidity_mapping: Option<EnhancedSnark>snark_tx: Option<EnhancedSnark>snark_receipt: Option<EnhancedSnark>promise_commit_keccak: FrThe keccak commit is provided as a public input. The SubqueryAggregation circuit will check that all subquery component circuits use the same promise commit for keccak. It will not check the promise commit itself. That will be done by AxiomAggregation1, which aggregates this SubqueryAggregation circuit.
snark_results_root: EnhancedSnarkResults root snark always required
Implementations
Sourceimpl InputSubqueryAggregation
impl InputSubqueryAggregation
Sourcepub fn build(
self,
stage: CircuitBuilderStage,
circuit_params: AggregationCircuitParams,
kzg_params: &ParamsKZG<Bn256>,
) -> Result<AggregationCircuit>
pub fn build( self, stage: CircuitBuilderStage, circuit_params: AggregationCircuitParams, kzg_params: &ParamsKZG<Bn256>, ) -> Result<AggregationCircuit>
Builds general circuit
Warning: this MUST return a circuit implementing CircuitExt with accumulator indices provided.
In particular, do not return BaseCircuitBuilder.
pub fn prover_circuit( self, pinning: AggregationCircuitPinning, kzg_params: &ParamsKZG<Bn256>, ) -> Result<AggregationCircuit>